@@ -1,4 +1,4 @@
-# Copyright (C) 2016-2019 by the Free Software Foundation, Inc.
+# Copyright (C) 2016-2022 by the Free Software Foundation, Inc.
 #
 # This file is part of GNU Mailman.
 #
@@ -27,9 +27,13 @@ from mailman.interfaces.cache import ICacheManager
 from mailman.interfaces.domain import IDomain
 from mailman.interfaces.mailinglist import IMailingList
 from mailman.interfaces.template import (
-    ALL_TEMPLATES, ALT_TEMPLATE_NAMES, ITemplateLoader, ITemplateManager)
+    ALL_TEMPLATES,
+    ALT_TEMPLATE_NAMES,
+    ITemplateLoader,
+    ITemplateManager,
+)
 from mailman.utilities import protocols
-from mailman.utilities.i18n import TemplateNotFoundError, find
+from mailman.utilities.i18n import find, TemplateNotFoundError
 from mailman.utilities.string import expand
 from public import public
 from requests import HTTPError
@@ -55,6 +59,7 @@ class Template(Model):
     password = Column(SAUnicode, nullable=True)
 
     def __init__(self, name, context, uri, username, password):
+        super().__init__()
         self.name = name
         self.context = context
         self.reset(uri, username, password)
